Dicom.SR.ContextGroup.Registry (Dicom v0.9.1)

Copy Markdown View Source

Generated CID registry for DICOM SR context groups.

Contains 1223 context groups with include-chain resolved codes. Generated via mix dicom.gen_context_groups from PS3.16 data.

Summary

Functions

Returns whether the given CID is extensible.

Looks up a context group by CID number.

Checks whether a code is a member of the given CID.

Returns the number of context groups in the registry.

Functions

extensible?(cid)

@spec extensible?(non_neg_integer()) :: boolean() | :unknown_cid

Returns whether the given CID is extensible.

lookup(cid)

@spec lookup(non_neg_integer()) :: {:ok, map()} | :error

Looks up a context group by CID number.

member?(cid, scheme, value)

@spec member?(non_neg_integer(), String.t(), String.t()) :: boolean() | :unknown_cid

Checks whether a code is a member of the given CID.

size()

@spec size() :: non_neg_integer()

Returns the number of context groups in the registry.