Dicom.SR.Tcoord (Dicom v0.9.1)

Copy Markdown View Source

Temporal coordinate reference for SR content items.

Defines a temporal region in a waveform or time series by specifying a range type and one of: sample positions, time offsets, or datetime values.

Summary

Types

t()

@type t() :: %Dicom.SR.Tcoord{
  datetime_values: [String.t()],
  sample_positions: [pos_integer()],
  temporal_range_type: String.t(),
  time_offsets: [number()]
}

Functions

new(temporal_range_type, opts \\ [])

@spec new(
  String.t(),
  keyword()
) :: t()